/* Jalview - a java multiple alignment editor
 * Copyright (C) 1998  Michele Clamp
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 */
package jalview.io;

import jalview.datamodel.*;
import jalview.analysis.*;

import java.io.*;
import java.util.*;

public class PIRFile extends AlignFile {

  Vector words = new Vector();  //Stores the words in a line after splitting

  public PIRFile()
  {}

  public PIRFile(String inStr) {
    super(inStr);
  }

  public PIRFile(String inFile, String type) throws IOException {
    super(inFile,type);
  }

  public void parse() {
    try{
      String id, start, end;
      StringBuffer sequence;
      String line = null;
      while( (line = nextLine())!=null)
      {
        try{
          id = line.substring(line.indexOf(";") + 1, line.indexOf("/"));
          line = line.substring(line.indexOf("/") + 1);
          start = line.substring(0, line.indexOf("-"));
          end = line.substring(line.indexOf("-") + 1);
        }catch(Exception ex)
        {  id="No id"; start="0"; end="0"; }

        sequence = new StringBuffer();

        line = nextLine(); // this is the title line

        boolean starFound = false;
        do
        {
          line = nextLine();
          sequence.append( line );
          if(line.indexOf("*")>-1)
            starFound = true;

        }while(!starFound);

        sequence.setLength( sequence.length()-1);

       Sequence newSeq = new Sequence(id,
                               sequence.toString(),
                               Integer.parseInt(start),
                               Integer.parseInt(end));
         seqs.addElement(newSeq);
      }

    }
    catch(Exception ex){ex.printStackTrace();}
  }

  public String print() {
    return print(getSeqsAsArray());
  }
  public static String print(SequenceI[] s) {
    return print(s,72,true);
  }
  public static String print(SequenceI[] s, int len) {
    return print(s,len,true);
  }
  public static String print(SequenceI[] s, int len,boolean gaps) {
    StringBuffer out = new StringBuffer();
    int i = 0;

    while (i < s.length && s[i] != null) {
      String seq = "";
      if (gaps) {
        seq = s[i].getSequence() + "*";
      } else {
        seq = AlignSeq.extractGaps(s[i].getSequence(),"-");
        seq = AlignSeq.extractGaps(seq,".");
        seq = AlignSeq.extractGaps(seq," ");
        seq = seq + "*";
      }

      out.append(">P1;" + s[i].getName() + "/" + s[i].getStart()+ "-" + s[i].getEnd() + "\n");
      out.append(" Dummy title\n");
      int nochunks = seq.length() / len + 1;

      for (int j = 0; j < nochunks; j++) {
        int start = j*len;
        int end = start + len;

        if (end < seq.length()) {
          out.append(seq.substring(start,end) + "\n");
        } else if (start < seq.length()) {
          out.append(seq.substring(start) + "\n");
        }
      }
      i++;
    }
    return out.toString();
  }

  public static void main(String[] args) {
    String inStr = ">P1;LCAT_MOUSE_90.35\nMGLPGSPWQRVLLLLGLLLPPATPFWLLNVLFPPHTTPKAELSNHTRPVILVPGCLGNRLEAKLDKPDVVNW\nMCYRKTEDFFTIWLDFNLFLPLGVDCWIDNTRIVYNHSSGRVSNAPGVQIRVPGFGKTESVEYVDDNKLAGY\n\n>LCAT_PAPAN_95.78\nMGPPGSPWQWVPLLLGLLLPPAAPFWLLNVLFPPHTTPKAELSNHTRPVILVPGCLGNQLEAKLDKPDVVNW\nMCYRKTEDFFTIWLDLNMFLPLGVDCWIDNTRVVYNRSSGLVSNAPGVQIRVPGFGKTYSVEYLDSSKLAGY\nLHTLVQNLVNNGYVRDETVRAAPYDWRLEPGQQEEYYHKLAGLVEEMHAAYGKPVFLIGHSLGCLHLLYFLL\n";
    PIRFile fa = new PIRFile(inStr);
  }
}



